import { Mapper } from '@automapper/core';
import { InjectMapper } from '@automapper/nestjs';
import { CommandHandler } from '@nestjs/cqrs';
import { ConfigurationRepository } from '../../adapters/secondaries/configuration.repository';
import { CreateConfigurationCommand } from '../../commands/create-configuration.command';
import { CreateConfigurationRequest } from '../dtos/create-configuration.request';
import { Configuration } from '../entities/configuration';

@CommandHandler(CreateConfigurationCommand)
export class CreateConfigurationUseCase {
  constructor(
    private readonly _repository: ConfigurationRepository,
    @InjectMapper() private readonly _mapper: Mapper,
  ) {}

  async execute(command: CreateConfigurationCommand): Promise<Configuration> {
    const entity = this._mapper.map(
      command.createConfigurationRequest,
      CreateConfigurationRequest,
      Configuration,
    );

    try {
      const configuration = await this._repository.create(entity);
      return configuration;
    } catch (error) {
      throw error;
    }
  }
}
